from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="dir2prompts",
    version="0.1.0",
    author="WangZhiZhou",
    author_email="jenojeff66@gmail.com",
    description="一个生成目录树结构的命令行工具",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Jeffjeno/dir2prompt",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.7",
    keywords=["directory", "tree", "file-structure", "command-line"],
    license="MIT",
    entry_points={
        "console_scripts": [
            "dir2prompt=dir2prompt.main:main",
        ],
    },
)